require 'spec_helper'

class MuppetsController < ActionController::Base
  def index
  end
end

describe SuchMeta::ControllerExtensions do
  subject { MuppetsController.new }

  before do
    I18n.backend.load_translations('spec/data/test.yml')
  end

  context 'SuchMeta module' do
    it 'should be mixed into ActionController::Base' do
      expect(ActionController::Base.included_modules).to include(SuchMeta::ControllerExtensions)
    end

    it "should respond to 'such_meta' helper" do
      expect(subject).to respond_to(:such_meta)
    end
  end

  describe '#such_meta' do
    let(:tag_type) { :title }
    let(:value) { nil }
    let(:default_translation_key) { "such_meta.default.#{tag_type}" }

    context 'specific translation is not provided' do
      it 'returns default translation for tag_type' do
        expect(subject.such_meta(tag_type)).to eq(I18n.t(default_translation_key))
      end
    end

    context 'overriding the defaults' do
      context 'via a controller/action specific translation' do
        before do
          ActionController::Base.any_instance.stub(:controller_name).and_return('muppets')
          ActionController::Base.any_instance.stub(:action_name).and_return('show')
        end

        let(:specific_translation_key) { "such_meta.specific.muppets.show.#{tag_type}" }

        it 'returns specific translation for tag_type' do
          expect(subject.such_meta(tag_type)).to eq(I18n.t(specific_translation_key))
        end
      end

      context 'via a value passed in' do
        let(:value) { 'Sample String' }

        it 'returns overriden translation for tag_type' do
          subject.such_meta(tag_type, value)
          expect(subject.such_meta(tag_type)).to eq(value)
        end
      end
    end
  end
end
